<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/compresseur?lang_cible=gl
// ** ne pas modifier le fichier **

return [

	// I
	'info_compresseur_titre' => 'Optimización e compresión',
	'info_question_activer_compactage_css' => 'Quere activar a compactación das follas de estilo(CSS) ?', # MODIF
	'info_question_activer_compactage_js' => 'Quere activar a compactación de scripts (javascript) ?', # MODIF

	// T
	'texte_compacter_avertissement' => 'Atención para non activar estas opcións durante o desenvolvemento do seu web: os elementos compactados perden toda a súa lexibilidade.',
	'texte_compacter_script_css' => 'SPIP pode compactar os scripts javascript e as follas de estilo CSS, para rexistralos nas fichas estáticas ; iso acelera a presentación do web.',
	'titre_compacter_script_css' => 'Compactación de scripts e CSS',
];
